import { Component, EventEmitter, Inject, Input, NgModule, Output, ViewChild } from '@angular/core';
import { CommonModule } from '@angular/common';
import { factories, models, service } from 'powerbi-client';

var PowerBIComponentComponent = (function () {
    /**
     * @param {?} powerBIService
     */
    function PowerBIComponentComponent(powerBIService) {
        this.powerBIService = powerBIService;
        this.embedded = new EventEmitter();
    }
    /**
     * @return {?}
     */
    PowerBIComponentComponent.prototype.ngOnInit = function () {
        var _a = this, accessToken = _a.accessToken, tokenType = _a.tokenType, embedUrl = _a.embedUrl, type = _a.type, id = _a.id;
        var /** @type {?} */ config = { accessToken: accessToken, tokenType: this.getTokenType(tokenType), embedUrl: embedUrl, type: type, id: id };
        if (this.validateOptions(accessToken, embedUrl)) {
            this.embed(this.powerbiFrame.nativeElement, config);
        }
    };
    /**
     * @param {?} changes
     * @return {?}
     */
    PowerBIComponentComponent.prototype.ngOnChanges = function (changes) {
        var accessToken = changes.accessToken, tokenType = changes.tokenType, embedUrl = changes.embedUrl, type = changes.type, id = changes.id;
        if (accessToken.previousValue === accessToken.currentValue
            || embedUrl.previousValue === embedUrl.currentValue) {
            return;
        }
        if (this.validateOptions(accessToken.currentValue, embedUrl.currentValue)) {
            /* check if change value was provided in changes
             to prevent error accessing to a property of undefined */
            var /** @type {?} */ config = {
                accessToken: accessToken && accessToken.currentValue,
                tokenType: tokenType ? this.getTokenType(tokenType.currentValue) : models.TokenType.Aad,
                embedUrl: embedUrl && embedUrl.currentValue,
                type: type && type.currentValue,
                id: id && id.currentValue
            };
            this.embed(this.powerbiFrame.nativeElement, config);
        }
        else if (this.component) {
            this.reset(this.powerbiFrame.nativeElement);
        }
    };
    /**
     * Validates if needed accessToken and embedUrl aren't empty and are strings
    \@param {string} accessToken - access token to embed component, obtained through pbi rest api
    \@param {string} embedUrl - url obtained through pbi rest api or pbi app
    \@return {boolean}
     * @param {?} accessToken
     * @param {?} embedUrl
     * @return {?}
     */
    PowerBIComponentComponent.prototype.validateOptions = function (accessToken, embedUrl) {
        if (!(typeof embedUrl === 'string' && embedUrl.length > 0)
            || !(typeof accessToken === 'string' && accessToken.length > 0)) {
            return false;
        }
        return true;
    };
    /**
     * Get the token type class or enum from string ('Embed' or 'Aad')
    \@param {string} tokenType - token type class name in string it must be 'Embed' or 'Aad'
    \@return {models.TokenType}
     * @param {?} tokenType
     * @return {?}
     */
    PowerBIComponentComponent.prototype.getTokenType = function (tokenType) {
        // convert token type string to model class to avoid import of powerbi-client in app
        if (!tokenType || tokenType.length < 0) {
            // default is AAD
            return models.TokenType.Aad;
        }
        else {
            // capitalize
            tokenType = tokenType.charAt(0).toUpperCase() + tokenType.toLowerCase().slice(1);
            return models.TokenType[tokenType];
        }
    };
    /**
     * Executes an embeding operation with pbi client library
    and assign the embed component to a property
    \@param {HTMLEelement} element - native element to embed pbi dashboard, report, or whatever
    \@param {IEmbedConfiguration} config - configuration to embed
    \@param {string} config.accessToken - access token to embed component, obtained through pbi rest api
    \@param {string} config.tokenType - type of accessToken, the most common is TokenType.Embed
    \@param {string} config.embedUrl - url obtained through pbi rest api or pbi app
    \@param {string} config.type - type of embedded component, like 'report' or 'dashboard'
    \@param {string} config.id - component/element id like '5dac7a4a-4452-46b3-99f6-a25915e0fe55'
     * @param {?} element
     * @param {?} config
     * @return {?}
     */
    PowerBIComponentComponent.prototype.embed = function (element, config) {
        this.component = this.powerBIService.embed(element, config);
        this.embedded.emit(((this.component)));
    };
    /**
     * Reset the component to delete the last embedded component
    \@param {HTMLElement} element - native element where the embedded was made
     * @param {?} element
     * @return {?}
     */
    PowerBIComponentComponent.prototype.reset = function (element) {
        this.powerBIService.reset(element);
        this.component = null;
    };
    return PowerBIComponentComponent;
}());
PowerBIComponentComponent.decorators = [
    { type: Component, args: [{
                selector: 'powerbi-component',
                template: '<div style="height:100%; width: 100%;" class="powerbi-frame" #powerbiFrame></div>',
            },] },
];
/**
 * @nocollapse
 */
PowerBIComponentComponent.ctorParameters = function () { return [
    { type: service.Service, decorators: [{ type: Inject, args: ['PowerBIService',] },] },
]; };
PowerBIComponentComponent.propDecorators = {
    'accessToken': [{ type: Input },],
    'tokenType': [{ type: Input },],
    'embedUrl': [{ type: Input },],
    'type': [{ type: Input },],
    'id': [{ type: Input },],
    'embedded': [{ type: Output },],
    'powerbiFrame': [{ type: ViewChild, args: ['powerbiFrame',] },],
};

/**
 * @return {?}
 */
function powerBiServiceFactory() {
    return new service.Service(factories.hpmFactory, factories.wpmpFactory, factories.routerFactory);
}
var PowerBIModule = (function () {
    function PowerBIModule() {
    }
    /**
     * @return {?}
     */
    PowerBIModule.forRoot = function () {
        return {
            ngModule: PowerBIModule
        };
    };
    return PowerBIModule;
}());
PowerBIModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    PowerBIComponentComponent
                ],
                providers: [
                    { provide: 'PowerBIService', useFactory: powerBiServiceFactory } // To inject a instance of pbi client library
                ],
                exports: [
                    PowerBIComponentComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
PowerBIModule.ctorParameters = function () { return []; };

export { powerBiServiceFactory, PowerBIModule, PowerBIComponentComponent };
